[at-spi2-core] Starting to improve atspi-collection



commit 4b65b5e83bb0c7afb4919eac0c9757d31ade536b
Author: Aline Bessa <alibezz gmail com>
Date:   Tue Jul 26 13:17:57 2011 -0300

    Starting to improve atspi-collection

 atspi/atspi-collection.c |   23 ++++++++++++-----------
 1 files changed, 12 insertions(+), 11 deletions(-)
---
diff --git a/atspi/atspi-collection.c b/atspi/atspi-collection.c
index 43dfa2f..5dd9bf8 100644
--- a/atspi/atspi-collection.c
+++ b/atspi/atspi-collection.c
@@ -26,21 +26,22 @@
 /* TODO: Improve documentation and implement some missing functions */
 
 /**
- * atspi_collection_is_ancester_of:
+ * atspi_collection_is_ancestor_of:
  *
  * @collection: The #AtspiCollection to test against.
  * @test: The #AtspiAccessible to test.
  *
+ * Not yet implemented. 
+ *
  * Returns: TRUE if @collection is an ancestor of @test; FALSE otherwise.
  *
- * Not yet implemented.
  **/
 gboolean
 atspi_collection_is_ancestor_of (AtspiCollection *collection,
                                  AtspiAccessible *test,
                                  GError **error)
 {
-  g_warning ("Atspi: TODO: Implement is_ancester_of");
+  g_warning ("Atspi: TODO: Implement is_ancestor_of");
   return FALSE;
 }
 
@@ -107,8 +108,8 @@ return_accessibles (DBusMessage *message)
 /**
  * atspi_collection_get_matches:
  *
  * @collection: The #AtspiCollection.
  * @rule: A #AtspiMatchRule describing the match criteria.
  * @sortby: An #AtspiCollectionSortOrder specifying the way the results are to
  *          be sorted.
  * @count: The maximum number of results to return, or 0 for no limit.
@@ -149,9 +150,9 @@ atspi_collection_get_matches (AtspiCollection *collection,
 /**
  * atspi_collection_get_matches_to:
  *
- * @collection: The #AtspiCollection.
+ * @collection: A pointer to the #AtspiCollection to query.
  * @current_object: The object at which to start searching.
- * @rule: A #AtspiMatchRule describing the match criteria.
+ * @rule: An #AtspiMatchRule describing the match criteria.
  * @sortby: An #AtspiCollectionSortOrder specifying the way the results are to
  *          be sorted.
  * @tree: An #AtspiCollectionTreeTraversalType specifying restrictions on
@@ -205,9 +206,9 @@ atspi_collection_get_matches_to (AtspiCollection *collection,
 /**
  * atspi_collection_get_matches_from:
  *
- * @collection: The #AtspiCollection.
+ * @collection: A pointer to the #AtspiCollection to query.
  * @current_object: Upon reaching this object, searching should stop.
- * @rule: A #AtspiMatchRule describing the match criteria.
+ * @rule: An #AtspiMatchRule describing the match criteria.
  * @sortby: An #AtspiCollectionSortOrder specifying the way the results are to
  *          be sorted.
  * @tree: An #AtspiCollectionTreeTraversalType specifying restrictions on
@@ -257,7 +258,7 @@ atspi_collection_get_matches_from (AtspiCollection *collection,
 /**
  * atspi_collection_get_active_descendant:
  * 
- * @collection: The #AtspiCollection to query.
+  @collection: A pointer to the #AtspiCollection to query.
  *
  * Returns: (transfer full): The active descendant of #collection.
  *
@@ -26,21 +26,22 @@
  *
- * @collection: The #AtspiCollection to test against.
+ * @collection: A pointer to the #AtspiCollection to test against.
  * @test: The #AtspiAccessible to test.
  *
@@ -107,8 +108,8 @@ return_accessibles (DBusMessage *message)
  * atspi_collection_get_matches:
  *
- * @collection: The #AtspiCollection.
- * @rule: A #AtspiMatchRule describing the match criteria.
+ * @collection: A pointer to the #AtspiCollection to query.
+ * @rule: An #AtspiMatchRule describing the match criteria.
  * @sortby: An #AtspiCollectionSortOrder specifying the way the results are to
  *          be sorted.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]